@@ -40,15 +40,19 @@ class PyQT_markdown(QWidget):
         with open(filepath, 'r') as file:
             data = file.read()
             html = markdown(data)
+        # print(html)
+        # html = '<html><body>this is a test</body></html>'
         view.setHtml(html)
 
 
 if __name__ == '__main__':
     import sys
 
+    # nothing is displayed --> WHY
+
     app = QApplication(sys.argv)
     w = PyQT_markdown()
     w.show()
-    w.set_markdown_from_file("../../docs/test.md")
-    w.set_markdown_from_file("../../docs/test.md")
+    w.set_markdown_from_file("../deeplearning/docs/getting_started.md")
+    w.set_markdown_from_file("../deeplearning/docs/getting_started2.md")
     sys.exit(app.exec_())
